<?php
/**
 * Ce fichier contient les fonctions d'API du plugin Territoires utilisées comme filtre dans les squelettes.
 * Les autres fonctions de l'API sont dans les fichiers `inc/territoire` et `inc/territoires_services`.
 *
 * @package SPIP\TERRITOIRES\API
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Fournit l'ascendance géographique d'un territoire, par consultation dans la base de données.
 *
 * @api
 * @filtre
 *
 * @param string      $iso_territoire Code ISO principal du territoire
 * @param string|null $iso_parent     Code ISO principal du parent direct du territoire concerné ou chaine vide sinon
 * @param string      $ordre          Classement de la liste : `descendant`(défaut) ou `ascendant`.
 *
 * @return array Liste des territoires ascendants.
 */
function territoire_informer_ascendance($iso_territoire, $iso_parent = null, $ordre = 'descendant') {

	$ascendance = array();

	// Si on ne passe pas le parent correspondant au territoire pour lequel on cherche l'ascendance
	// alors on le cherche en base de données.
	// Le fait de passer le parent est uniquement une optimisation.
	if (\is_null($iso_parent)) {
		$iso_parent = sql_getfetsel('iso_parent', 'spip_territoires', 'iso_territoire=' . sql_quote($iso_territoire));
	}

	while ($iso_parent) {
		$select = array('id_territoire', 'iso_parent', 'nom_usage', 'type', 'categorie');
		$where = array('iso_territoire=' . sql_quote($iso_parent));
		$territoire = sql_fetsel($select, 'spip_territoires', $where);
		if ($territoire) {
			$ascendance[] = $territoire;
			$iso_parent = $territoire['iso_parent'];
		} else {
			// Le parent est d'un autre type qui n'est pas encore peuplé en base : on s'arrête.
			$iso_parent = '';
		}
	}

	if ($ascendance	and ($ordre == 'descendant')) {
		$ascendance = array_reverse($ascendance);
	}

	return $ascendance;
}
